@@ -10,4 +10,4 @@ class RYU:
     LOG_FILE_ARG = "--log-file"
     CONTROLLER_PORT_ARG = "--ofp-tcp-listen-port"
     WEB_APP_PORT_ARG = "--wsapi-port"
-    RYU_MANAGER = "ryu-manager"
+    RYU_MANAGER = "/root/miniconda3/bin/ryu-manager"
